From: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
To: linux-acpi@vger.kernel.org, linux-kernel@vger.kernel.org,
linux-mm@kvack.org
Cc: len.brown@intel.com, wency@cn.fujitsu.com
Subject: [PATCH 2/2] acpi,memory-hotplug : call acpi_bus_remo() to remove memory device
Date: Thu, 4 Oct 2012 10:48:10 +0900 [thread overview]
Message-ID: <506CEADA.9060108@jp.fujitsu.com> (raw)
In-Reply-To: <506CE9F5.8020809@jp.fujitsu.com>
From: Wen Congyang <wency@cn.fujitsu.com>
The memory device has been ejected and powoffed, so we can call
acpi_bus_remove() to remove the memory device from acpi bus.
CC: Len Brown <len.brown@intel.com>
Reviewed-by: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
Signed-off-by: Wen Congyang <wency@cn.fujitsu.com>
---
drivers/acpi/acpi_memhotplug.c | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
Index: linux-3.6/drivers/acpi/acpi_memhotplug.c
===================================================================
--- linux-3.6.orig/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:47.802249170 +0900
+++ linux-3.6/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:52.471250299 +0900
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
* TBD: Invoke acpi_bus_remove to cleanup data structures
*/
+ acpi_bus_remove(device, 1);
/* _EJ0 succeeded; _OST is not necessary */
return;
WARNING: multiple messages have this Message-ID (diff)
From: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
To: linux-acpi@vger.kernel.org, linux-kernel@vger.kernel.org,
linux-mm@kvack.org
Cc: len.brown@intel.com, wency@cn.fujitsu.com
Subject: [PATCH 2/2] acpi,memory-hotplug : call acpi_bus_remo() to remove memory device
Date: Thu, 4 Oct 2012 10:48:10 +0900 [thread overview]
Message-ID: <506CEADA.9060108@jp.fujitsu.com> (raw)
In-Reply-To: <506CE9F5.8020809@jp.fujitsu.com>
From: Wen Congyang <wency@cn.fujitsu.com>
The memory device has been ejected and powoffed, so we can call
acpi_bus_remove() to remove the memory device from acpi bus.
CC: Len Brown <len.brown@intel.com>
Reviewed-by: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
Signed-off-by: Wen Congyang <wency@cn.fujitsu.com>
---
drivers/acpi/acpi_memhotplug.c | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
- * TBD: Invoke acpi_bus_remove to cleanup data structures
+ * Invoke acpi_bus_remove() to remove memory device
*/
Index: linux-3.6/drivers/acpi/acpi_memhotplug.c
===================================================================
--- linux-3.6.orig/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:47.802249170 +0900
+++ linux-3.6/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:52.471250299 +0900
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
* TBD: Invoke acpi_bus_remove to cleanup data structures
*/
+ acpi_bus_remove(device, 1);
/* _EJ0 succeeded; _OST is not necessary */
return;
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
- * TBD: Invoke acpi_bus_remove to cleanup data structures
+ * Invoke acpi_bus_remove() to remove memory device
*/
--
To unsubscribe, send a message with 'unsubscribe linux-mm' in
the body to majordomo@kvack.org. For more info on Linux MM,
see: http://www.linux-mm.org/ .
Don't email: <a href=mailto:"dont@kvack.org"> email@kvack.org </a>
WARNING: multiple messages have this Message-ID (diff)
From: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
To: <linux-acpi@vger.kernel.org>, <linux-kernel@vger.kernel.org>,
<linux-mm@kvack.org>
Cc: <len.brown@intel.com>, <wency@cn.fujitsu.com>
Subject: [PATCH 2/2] acpi,memory-hotplug : call acpi_bus_remo() to remove memory device
Date: Thu, 4 Oct 2012 10:48:10 +0900 [thread overview]
Message-ID: <506CEADA.9060108@jp.fujitsu.com> (raw)
In-Reply-To: <506CE9F5.8020809@jp.fujitsu.com>
From: Wen Congyang <wency@cn.fujitsu.com>
The memory device has been ejected and powoffed, so we can call
acpi_bus_remove() to remove the memory device from acpi bus.
CC: Len Brown <len.brown@intel.com>
Reviewed-by: Yasuaki Ishimatsu <isimatu.yasuaki@jp.fujitsu.com>
Signed-off-by: Wen Congyang <wency@cn.fujitsu.com>
---
drivers/acpi/acpi_memhotplug.c | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
Index: linux-3.6/drivers/acpi/acpi_memhotplug.c
===================================================================
--- linux-3.6.orig/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:47.802249170 +0900
+++ linux-3.6/drivers/acpi/acpi_memhotplug.c 2012-10-03 18:17:52.471250299 +0900
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
* TBD: Invoke acpi_bus_remove to cleanup data structures
*/
+ acpi_bus_remove(device, 1);
/* _EJ0 succeeded; _OST is not necessary */
return;
next prev parent reply other threads:[~2012-10-04 1:48 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2012-10-04 1:44 [PATCH 0/2] acpi,memory-hotplug : remove memory device by acpi_bus_remove() Yasuaki Ishimatsu
2012-10-04 1:44 ` Yasuaki Ishimatsu
2012-10-04 1:44 ` Yasuaki Ishimatsu
2012-10-04 1:46 ` [PATCH 1/2] acpi,memory-hotplug : export the function acpi_bus_remove() Yasuaki Ishimatsu
2012-10-04 1:46 ` Yasuaki Ishimatsu
2012-10-04 1:46 ` Yasuaki Ishimatsu
2012-10-04 1:48 ` Yasuaki Ishimatsu [this message]
2012-10-04 1:48 ` [PATCH 2/2] acpi,memory-hotplug : call acpi_bus_remo() to remove memory device Yasuaki Ishimatsu
2012-10-04 1:48 ` Yasuaki Ishimatsu
2012-10-04 2:41 ` Yinghai Lu
2012-10-04 2:41 ` Yinghai Lu
2012-10-19 1:50 ` Wen Congyang
2012-10-19 1:50 ` Wen Congyang
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=506CEADA.9060108@jp.fujitsu.com \
--to=isimatu.yasuaki@jp.fujitsu.com \
--cc=len.brown@intel.com \
--cc=linux-acpi@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mm@kvack.org \
--cc=wency@cn.fujitsu.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -424,8 +424,9 @@ static void acpi_memory_device_notify(ac
}
/*
- * TBD: Invoke acpi_bus_remove to cleanup data structures
+ * Invoke acpi_bus_remove() to remove memory device
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.